@@ -24,10 +24,7 @@ class RequestData:
         self.action = action
         self.resource = resource
         self.options = {}
-        if params is None:
-            self.params = {}
-        else:
-            self.params = params
+        self.params = params or {}
 
         if global_options:
             self.set_options(OptionsType.REQUEST, global_options)
