@@ -15,12 +15,10 @@ class GlobalOptions(GlobalOptionsBase):
     saml_clients: Dict[str, SAMLClient] = field(default_factory=dict)
     session_length: Optional[int] = None
     aws_region: Optional[str] = None
-    disable_analytics: bool = False
 
     def to_dict(self):
         return {
-            "debug": self.debug,
-            "disable_analytics": self.disable_analytics,
+            **super().to_dict(),
             "saml_client": str(self.saml_client_type),
             "session_length": str(self.session_length),
             "aws_region": str(self.aws_region),
