@@ -4,8 +4,9 @@ from configparser import ConfigParser, NoOptionError
 from pathlib import Path
 from typing import Final, Iterator, Optional, Tuple
 
+import click
 from semver import VersionInfo
-from sym.shared.cli.helpers.contexts import push_env
+from sym.shared.cli.helpers.contexts import push_envs
 from sym.shared.cli.helpers.keywords_to_options import (
     Argument,
     Options,
@@ -25,6 +26,7 @@ from ..helpers.params import Profile, get_saml2aws_params
 from .saml_client import SAMLClient
 
 MIN_VERSION = VersionInfo.parse("2.26.2")
+PREFERRED_VERSION = VersionInfo.parse("2.28.3")
 
 ErrorPatterns = {
     Saml2AwsNoRoles: UnavailableResourceError,
@@ -67,7 +69,17 @@ class Saml2Aws(SAMLClient):
         ).stderr
         if not version:
             return False
-        return VersionInfo.parse(version.strip()) >= MIN_VERSION
+
+        parsed = VersionInfo.parse(version.strip())
+        if parsed < MIN_VERSION:
+            return False
+        if parsed < PREFERRED_VERSION:
+            click.secho(
+                f"Hint: Your version of saml2aws has a bug that will cause double Okta prompts. Try upgrading to at least {PREFERRED_VERSION}.\n",
+                err=True,
+                fg="cyan",
+            )
+        return True
 
     def is_setup(self) -> bool:
         path = Path.home() / ".saml2aws"
@@ -87,6 +99,12 @@ class Saml2Aws(SAMLClient):
                 continue
         return False
 
+    def _saml2aws_envs(self) -> dict:
+        return {
+            "AWS_REGION": self.ensure_config()[self._section_name]["region"],
+            "SAML2AWS_CACHE_SAML": "true",
+        }
+
     @intercept_errors(ErrorPatterns)
     @run_subprocess
     @command_require_bins(binary)
@@ -94,7 +112,7 @@ class Saml2Aws(SAMLClient):
         # saml2aws exec actually joins all the arguments into a single string and
         # runs it with the shell. So we have to use shlex.join to get around that!
         reparseable = shlex.join(keywords_to_options([*args, opts]))
-        with push_env("AWS_REGION", self.ensure_config()[self._section_name]["region"]):
+        with push_envs(self._saml2aws_envs()):
             yield (
                 "saml2aws",
                 self._s2a_options,
@@ -113,7 +131,7 @@ class Saml2Aws(SAMLClient):
         else:
             options = self._s2a_options
             args = {}
-        with push_env("AWS_REGION", self.ensure_config()[self._section_name]["region"]):
+        with push_envs(self._saml2aws_envs()):
             # no-op if session active when force=False
             yield "saml2aws", options, "login", args, {"force": force}
 
